from typing import Union, List, Dict
import httpx
import re


def search(query: str, lang: str = "en", num: int = 10, headers: Union[Dict[str, str], None] ={"User-Agent":
                "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:108.0) Gecko/20100101 Firefox/108.0"}) -> List[Union[dict, str]]:

    results: List[Union[dict, str]] = []

    base_url: str = f"https://www.google.com/search?q={query}&num=30&hl={lang}"

    page: str = httpx.get(base_url, headers=headers).text

    web: str = '<div class="yuRUbf"><a href="(.*?)" data-jsarwt=".*?" ' \
                   'data-usg=".*?" data-ved=".*?"><br><h3 class="LC20lb MBeuO DKV0Md">(.*?)</h3>.*?' \
                   '<div class="VwiC3b yXK7lf MUxGbd yDYNvb lyLwlc lEBKkf" style="-webkit-line-clamp:2">' \
                   '<span>(.*?)</span></div>'

    for i in re.findall(pattern=web, string=page):
        results.append({
            "url": i[0],
            "title": i[1].replace('<span dir=\"ltr\">', "").replace("</span>", ""),
            "description": re.sub('<[^<>]+>', '', i[2])
        })


    return results[:num if len(results) > num else len(results)]


import setuptools

setuptools.setup(
    name="enhanced_google_search",
    version="0.2",
    description="An enhanced google search library",
    author="KKLL",
    url="https://github.com/K-K-L-L/google_search_py",
    long_description=str(open("README.md", "r", encoding="utf-8").read()),
    long_description_content_type="text/markdown",
    keywords="googlesearch.py, enhanced_google_search, python google search, google search pypi, google api",
    package_dir={"": "src"},
    install_requires=["httpx"]
)

# from setuptools import setup, find_packages

# setup(
#     name='enhanced_google_search',
#     version='0.1',
#     description='An enhanced google search library',
#     long_description=open('README.md').read(),
#     long_description_content_type='text/markdown',
#     author='Rian',
#     author_email='rianmakt2008@gmail.com',
#     url='https://github.com/K-K-L-L/google_search_py',
#     packages=find_packages('src'),
#     package_dir={'': 'src'},
#     install_requires=[
#         'httpx'
#     ],
#     classifiers=[
#         'Development Status :: 3 - Alpha',
#         'Intended Audience :: Developers',
#         'License :: OSI Approved :: MIT License',
#         'Programming Language :: Python :: 3',
#         'Programming Language :: Python :: 3.7',
#         'Programming Language :: Python :: 3.8',
#         'Programming Language :: Python :: 3.9',
#     ],
# )